@@ -1,7 +1,7 @@
 """connector.py
 
 Created on: May 19, 2017
-   Authors: Jeroen van der Heijden <jeroen@transceptor.technology>
+   Authors: Jeroen van der Heijden <jeroen@cesbit.com>
             jomido <https://github.com/jomido>
 """
 import os
@@ -257,6 +257,9 @@ class GcdConnector:
                             break
 
                         if more_results == 'NOT_FINISHED':
+                            if data['query'].get('limit'):
+                                data['query']['limit'] -= len(entity_results)
+                            data['query'].pop('offset', None)
                             continue
 
                         raise ValueError(
@@ -332,8 +335,8 @@ class GcdConnector:
 
     async def get_entities_by_keys(self, keys, missing=None, deferred=None,
                                    eventual=False):
-        """Returns entity objects for the given keys or None in case no
-        entity is found.
+        """Returns entity objects for the given keys or an empty list in case
+        no entity is found.
 
         :param keys: list of Key objects
         :return: list of Entity objects or None.
@@ -379,8 +382,7 @@ class GcdConnector:
 
                     keys = deferred_keys
 
-        if entities:
-            return entities
+        return entities
 
     async def get_entity_by_key(self, key, missing=None, deferred=None,
                                 eventual=False):
