@@ -1,7 +1,7 @@
 """__init__.py
 
 Created on: May 19, 2017
-    Author: Jeroen van der Heijden <jeroen@transceptor.technology>
+    Author: Jeroen van der Heijden <jeroen@cesbit.com>
 """
 from .integervalue import IntegerValue
 from .stringvalue import StringValue
@@ -13,3 +13,4 @@ from .keyvalue import KeyValue
 from .anyvalue import AnyValue
 from .datetimevalue import DatetimeValue
 from .entityvalue import EntityValue
+from .bytesvalue import BytesValue
